====================================================
pyetta - Python Embedded Test Toolbox and Automation
====================================================

Roadmap
==========

The current roadmap for features (in no specific order):

- Plugin support for registering loaders, runner, and parser
- Add support for env variables as options
- Tidy up CLI to run tests
- Add documentation and README for usage (install libusb/openocd)
- Add feature to load plugins via pypi (entrypoints API)
- Add plugins via options
- Add switches to force file formats (etc --fmt hex)
- Adjust cli naming
